@@ -162,7 +162,9 @@ void mainwindow::storevalues()
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /usr/share/hildon-desktop/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /usr/share/hildon-desktop/transitions.ini");
 
-    QString path3 = "/opt/theme-customizer/transitions.ini";
+    QString path3 = "/usr/share/hildon-desktop/transitions.ini";
+    if (QFile::exists("/opt/theme-customizer/transitions.ini")) {
+    path3 = "/opt/theme-customizer/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=50/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=100/g\" /opt/theme-customizer/transitions.ini");
@@ -181,6 +183,7 @@ void mainwindow::storevalues()
     if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /opt/theme-customizer/transitions.ini");
     if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /opt/theme-customizer/transitions.ini");
+    }
 
     QSettings settings(path, QSettings::IniFormat);
     QSettings settings2(path2, QSettings::IniFormat);
@@ -417,6 +420,6 @@ void mainwindow::on_pushButton_2_clicked()
 {
     QMessageBox msgBox;
     msgBox.setWindowTitle("CSSU Transitions Tuner");
-    msgBox.setText("CSSU Transitions Tuner ver. 0.0.3<br /><br />Auhtor: d-iivil<br />Licence: GPL");
+    msgBox.setText("CSSU Transitions Tuner ver. 0.0.4<br /><br />Auhtor: d-iivil<br />Licence: GPL");
     msgBox.exec();
 }
